qcacld-3.0: hdd: Rename pRoamInfo

The Linux Coding Style frowns upon mixed-case names and so-called
Hungarian notation, so rename pRoamInfo to align with the Coding
Style.

Change-Id: I39f76a4e11fb26c5ab4279ae0b02dddadd06a83b
CRs-Fixed: 2121188
diff --git a/core/hdd/inc/wlan_hdd_wmm.h b/core/hdd/inc/wlan_hdd_wmm.h
index fcb4334..67362e5 100644
--- a/core/hdd/inc/wlan_hdd_wmm.h
+++ b/core/hdd/inc/wlan_hdd_wmm.h
@@ -311,26 +311,26 @@
  * required by WMM when association takes place
  *
  * @adapter: [in]  pointer to adapter context
  * @pRoamInfo: [in]  pointer to roam information
  * @eBssType: [in]  type of BSS
  *
  * Return: QDF_STATUS enumeration
  */
 QDF_STATUS hdd_wmm_assoc(struct hdd_adapter *adapter,
-			 tCsrRoamInfo *pRoamInfo, eCsrRoamBssType eBssType);
+			 tCsrRoamInfo *roam_info, eCsrRoamBssType eBssType);
 
 /**
  * hdd_wmm_connect() - Function which will handle the housekeeping
  * required by WMM when a connection is established
  *
  * @adapter : [in]  pointer to adapter context
  * @pRoamInfo: [in]  pointer to roam information
  * @eBssType : [in]  type of BSS
  *
  * Return: QDF_STATUS enumeration
  */
 QDF_STATUS hdd_wmm_connect(struct hdd_adapter *adapter,
-			   tCsrRoamInfo *pRoamInfo, eCsrRoamBssType eBssType);
+			   tCsrRoamInfo *roam_info, eCsrRoamBssType eBssType);
 
 /**
  * hdd_wmm_get_uapsd_mask() - Function which will calculate the
@@ -311,26 +311,26 @@
  *
  * @adapter: [in]  pointer to adapter context
- * @pRoamInfo: [in]  pointer to roam information
+ * @roam_info: [in]  pointer to roam information
  * @eBssType: [in]  type of BSS
  *
@@ -311,26 +311,26 @@
  *
  * @adapter : [in]  pointer to adapter context
- * @pRoamInfo: [in]  pointer to roam information
+ * @roam_info: [in]  pointer to roam information
  * @eBssType : [in]  type of BSS
  *